; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below.
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "Light Rising Rainbow"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

[Command]
name = "Talented Teaching"
command = ~D,B,c

time = 20

[Command]
name = "Talented Teaching"   ;Same name as above
command = ~D,D,c

time = 20

[Command]
name = "Perfect Play"
command = ~D,F,z
time = 20

[Command]
name = "Perfect Play"   ;Same name as above
command = ~D,F,c
time = 20

[Command]
name = "Numerous Noisy Notes"
command = ~D,D,x
time = 20

[Command]
name = "Numerous Noisy Notes"   ;Same name as above
command = ~D,D,y
time = 20

[Command]
name = "Really Rising Rainbow"
command = ~D,D,a
time = 20

[Command]
name = "Really Rising Rainbow"   ;Same name as above
command = ~D,D,b
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "blocking"
command = $F,x
time = 3

[Command]
name = "blocking" ;Same name as above (buttons in opposite order)
command = x,$F
time = 3

[Command]
name = "Light Noisy Note"
command = ~D, DF, F, x

[Command]
name = "Strong Noisy Note"
command = ~D, DF, F, y

[Command]
name = "Fast Noisy Note"
command = ~D, DF, F, x+y

[Command]
name = "Light Rising Rainbow"
command = ~D,B,x

[Command]
name = "Strong Rising Rainbow"
command = ~D,B,y

[Command]
name = "Fast Rising Rainbow"
command = ~D,B,x+y

[Command]
name = "Delightful Dance"
command = ~D,D,z

[Command]
name = "Lost Love"
command = ~D, DF, F, a

[Command]
name = "Lost Love"
command = ~D, DF, F, b

[Command]
name = "Fast Lost Love"
command = ~D,F,a+b

[Command]
name = "Air Beautiful Ballerina"
command = ~D,F,a
time = 15

[Command]
name = "Air Beautiful Ballerina"
command = ~D,F,b
time = 15

[Command]
name = "Fast Beautiful Ballerina"
command = ~D,B,a+b

[Command]
name = "Light Beautiful Ballerina"
command = ~D,B,a

[Command]
name = "Strong Beautiful Ballerina"
command = ~D,B,b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = z
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------

[Command]
name = "Liedown Attack"
command = /$U,x
time = 1
[Command]
name = "Liedown Attack"
command = /$U,y
time = 1
[Command]
name = "Liedown Attack"
command = /$U,a
time = 1
[Command]
name = "Liedown Attack"
command = /$U,b
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;---------------------------------------------------------------------------
[State -1,AION];turns the AI on if there is an ailevel
Type = VarSet
TriggerAll = Var(59) = 0
Trigger1 = AILevel
V = 59
Value = 1

;---------------------------------------------------------------------------
[State -1,AIOFF];turns the AI off if there isnt an ailevel
Type = VarSet
Trigger1 = !AILevel
V = 59
Value = 0


;---------------------------------------------------------------------------
[State -1, AI go to StandAI];if all these triggers are right then go to state 4000 and do an attack or something
type = ChangeState
value = 4000
triggerall = var(59) = 1 
triggerall = var(30) != 1 
triggerall = statetype != A 
triggerall = p2statetype != L
triggerall = p2bodydist x < 70 
triggerall = p2statetype != A 
triggerall = Ctrl = 1
trigger1 = Random < 500
Trigger2 = Time > (30-AILevel*2)

;---------------------------------------------------------------------------
[State -1, AI go to SpecialAI];same as above except if far away
type = ChangeState
value = 4050
triggerall = var(59) = 1 
triggerall = var(30) != 1 
triggerall = statetype != A 
triggerall = p2statetype != L
triggerall = p2bodydist x > 70 
triggerall = p2statetype != A 
triggerall = Ctrl
trigger1 = Random < 500
Trigger2 = Time > (90-AILevel*2)

;---------------------------------------------------------------------------
[State -1, AI go to AirAI];same as above but in air
type = ChangeState
value = 4100
triggerall = var(59) = 1 
triggerall = var(30) != 1 
triggerall = statetype = A 
triggerall = p2statetype != L
triggerall = Ctrl
trigger1 = Random < 500
Trigger2 = Time > (30-AILevel*2)


;===========================================================================

;Smash Kung Fu Upper (uses one super bar)
[State -1, Talented Teaching]
type = ChangeState
value = 3150
triggerall = command = "Talented Teaching"
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3050,3200)
trigger2 = movecontact
trigger3 = stateno = 1310 || stateno = 1330 ;From blocking

;---------------------------------------------------------------------------

;Smash Kung Fu Upper (uses one super bar)
[State -1, Perfect Play]
type = ChangeState
value = 3100
triggerall = command = "Perfect Play"
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3050,3100)
trigger2 = movecontact
trigger3 = stateno = 1310 || stateno = 1330 ;From blocking


;---------------------------------------------------------------------------
;Smash Kung Fu Upper (uses one super bar)
[State -1, Smash Kung Fu Upper]
type = ChangeState
value = 3050
triggerall = command = "Really Rising Rainbow"
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3050,3100)
trigger2 = movecontact
trigger3 = stateno = 1310 || stateno = 1330 ;From blocking

;---------------------------------------------------------------------------
;Triple Kung Fu Palm (uses one super bar)
[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3000
triggerall = command = "Numerous Noisy Notes"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3000,3050)
trigger2 = movecontact
trigger3 = stateno = 1310 || stateno = 1330 ;From blocking


;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact
trigger3 = stateno = 1310 || stateno = 1330 ;From blocking
var(1) = 1

;---------------------------------------------------------------------------
;Delightful Dance
[State -1, Delightful Dance]
type = ChangeState
value = 1200
triggerall = command = "Delightful Dance"
trigger1 = var(1) ;Use combo condition (above)
trigger1 = statetype = S
trigger1 = stateno !=260

;---------------------------------------------------------------------------
[State -1, Air Beautiful Ballerina]
type = ChangeState
value = 1080
triggerall = command = "Air Beautiful Ballerina"
triggerall = statetype = A
trigger1 = ctrl
trigger2 = stateno = [600,650]
trigger2 = movecontact
trigger3 = stateno = 100


;---------------------------------------------------------------------------
;Fast Beautiful Ballerina (1/3 super bar)
[State -1, Fast Beautiful Ballerina]
type = ChangeState
value = 1070
triggerall = command = "Fast Beautiful Ballerina"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)
trigger1 = stateno !=260

;---------------------------------------------------------------------------
;Light Beautiful Ballerina
[State -1, Light Beautiful Ballerina]
type = ChangeState
value = 1050
triggerall = command = "Light Beautiful Ballerina"
trigger1 = var(1) ;Use combo condition (above)
trigger1 = stateno !=260
;---------------------------------------------------------------------------
;Strong Beautiful Ballerina
[State -1, Strong Beautiful Ballerina]
type = ChangeState
value = 1060
triggerall = command = "Strong Beautiful Ballerina"
trigger1 = var(1) ;Use combo condition (above)
trigger1 = stateno !=260

;---------------------------------------------------------------------------
;Fast Rising Rainbow (1/3 super bar)
[State -1, Fast Rising Rainbow]
type = ChangeState
value = 1020
triggerall = command = "Fast Rising Rainbow"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)
trigger1 = stateno !=260

;---------------------------------------------------------------------------
;Light Rising Rainbow
[State -1, Light Rising Rainbow]
type = ChangeState
value = 1000
triggerall = command = "Light Rising Rainbow"
trigger1 = var(1) ;Use combo condition (above)
trigger1 = stateno !=260
;---------------------------------------------------------------------------
;Strong Rising Rainbow
[State -1, Strong Rising Rainbow]
type = ChangeState
value = 1010
triggerall = command = "Strong Rising Rainbow"
trigger1 = var(1) ;Use combo condition (above)
trigger1 = stateno !=260
;---------------------------------------------------------------------------
;Fast Noisy Note (1/3 super bar)
[State -1, Fast Noisy Note]
type = ChangeState
value = 1120
triggerall = command = "Fast Noisy Note"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)
trigger1 = stateno !=260
;---------------------------------------------------------------------------
;Light Noisy Note
[State -1, Light Kung Fu Upper]
type = ChangeState
value = 1100
triggerall = command = "Light Noisy Note"
trigger1 = var(1) ;Use combo condition (above)
trigger1 = stateno !=260
;---------------------------------------------------------------------------
;Strong Noisy Note
[State -1,Strong Noisy Note]
type = ChangeState
value = 1110
triggerall = command = "Strong Noisy Note"
trigger1 = var(1) ;Use combo condition (above)
trigger1 = stateno !=260
;---------------------------------------------------------------------------
;Fast
[State -1, Fast Lost Love]
type = ChangeState
value = 1420
triggerall = NumExplod(1405)=0; To keep player from keep stunning opponent
triggerall = command = "Fast Lost Love"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)
trigger1 = stateno !=260
;---------------------------------------------------------------------------
;Lost Love
[State -1, Lost Love]
type = ChangeState
value = 1400
triggerall = NumExplod(1405)=0
triggerall = command = "Lost Love"
trigger1 = var(1) ;Use combo condition (above)
trigger1 = stateno !=260
;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Sisterly Slap Throw
[State -1, Sisterly Slap Throw]
type = ChangeState
value = 800
triggerall = command = "y"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;---------------------------------------------------------------------------
;Romantic Kiss Throw
[State -1, Romantic Throw]
type = ChangeState
value = 830
triggerall = command = "b"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H


;===========================================================================
;Liedown Attack
[State -1, Liedown Attack]
type = ChangeState
value = 700
triggerall = enemy, statetype = L
triggerall = command = "Liedown Attack"
triggerall = statetype != A
;triggerall = var(10)
trigger1 = ctrl
trigger2 = stateno = 40

;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 6

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 201) && time > 5
trigger4 = (stateno = 230) && time > 6

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 7
trigger3 = (stateno = 201) && time > 5
trigger4 = (stateno = 230) && time > 9

;---------------------------------------------------------------------------
;Side Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 260
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = command = "holdfwd"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 201) && time > 5
trigger4 = (stateno = 230) && time > 6

;---------------------------------------------------------------------------
;Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 201) && time > 5
trigger4 = (stateno = 230) && time > 6

;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Charging
[State -1, Charging]
type = ChangeState
value = 750
triggerall = power !=3000
triggerall = command = "holdc"
trigger1 = !AILevel
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Dodge
[State -1, Dodge]
type = ChangeState
value = 760
trigger1 = command = "z"
trigger1 = command != "holdback"
trigger1 = command != "holdfwd"
trigger1 = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = hitdefattr = sca,aa,ap,at
trigger2 = statetype != A
trigger2 = ctrl

;---------------------------------------------------------------------------
;Dodge Forwards
[State -1, Dodge Forwards]
type = ChangeState
value = 761
trigger1 = command = "z"
trigger1 = command = "holdfwd"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = hitdefattr = sca,aa,ap,at
trigger2 = command = "holdfwd"
trigger2 = statetype != A
trigger2 = ctrl


;---------------------------------------------------------------------------
;Dodge Backwards
[State -1, Dodge Backwards]
type = ChangeState
value = 762
trigger1 = command = "z"
trigger1 = command = "holdback"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = hitdefattr = sca,aa,ap,at
trigger2 = command = "holdback"
trigger2 = statetype != A
trigger2 = ctrl

;---------------------------------------------------------------------------
;Dodge Down
[State -1, Dodge Down]
type = ChangeState
value = 763
trigger1 = command = "z"
trigger1 = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = hitdefattr = sca,aa,ap,at
trigger2 = command = "holddown"
trigger2 = statetype != A
trigger2 = ctrl


;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = statetime >= 7
trigger3 = stateno = 1350 ;Air blocking
trigger4 = stateno = 260 ;Side Kick

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking
trigger4 = stateno = 260 ;Side Kick

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking
trigger3 = stateno = 260 ;Side Kick

;---------------------------------------------------------------------------
;Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking
trigger4 = stateno = 260 ;Side Kick